@@ -1,5 +1,6 @@
+from ekp_sdk.db.contract_logs_repo import ContractLogsRepo
+from ekp_sdk.db.contract_transactions_repo import ContractTransactionsRepo
 from ekp_sdk.db.mg_client import MgClient
-
 from ekp_sdk.db.pg_client import PgClient
 from ekp_sdk.services.cache_service import CacheService
 from ekp_sdk.services.client_service import ClientService
@@ -7,10 +8,10 @@ from ekp_sdk.services.coingecko_service import CoingeckoService
 from ekp_sdk.services.etherscan_service import EtherscanService
 from ekp_sdk.services.redis_client import RedisClient
 from ekp_sdk.services.rest_client import RestClient
+from ekp_sdk.services.transaction_sync_service import TransactionSyncService
 from ekp_sdk.services.web3_service import Web3Service
 
 
-
 class BaseContainer:
     def __init__(self, config):
 
@@ -54,16 +55,28 @@ class BaseContainer:
                 base_url=ETHERSCAN_BASE_URL,
                 rest_client=self.rest_client
             )
+            self.contract_transactions_repo = ContractTransactionsRepo(
+                mg_client=self.mg_client,
+            )
+
+            self.contract_logs_repo = ContractLogsRepo(
+                mg_client=self.mg_client,
+            )
+            self.transaction_sync_service = TransactionSyncService(
+                contract_transactions_repo=self.contract_transactions_repo,
+                contract_logs_repo=self.contract_logs_repo,
+                etherscan_service=self.etherscan_service,
+            )
         else:
             print(
                 "⚠️ skipped EtherscanService init, missing ETHERSCAN_API_KEY and ETHERSCAN_BASE_URL")
 
-        if self.redis_client is not None:
+        if REDIS_URI is not None:
             self.cache_service = CacheService(
                 redis_client=self.redis_client,
             )
         else:
-            print("⚠️ skipped CacheService init, missing RedisClient")
+            print("⚠️ skipped CacheService init, missing REDIS_URI")
 
         if WEB3_PROVIDER_URL is not None:
             self.web3_service = Web3Service(
@@ -83,4 +96,3 @@ class BaseContainer:
         self.coingecko_service = CoingeckoService(
             rest_client=self.rest_client
         )
-
